@@ -1,9 +1,9 @@
 package Test::Smoke;
 use strict;
 
-# $Id: Smoke.pm 298 2003-07-31 21:03:26Z abeltje $
+# $Id: Smoke.pm 350 2003-08-08 22:26:08Z abeltje $
 use vars qw( $VERSION $conf @EXPORT );
-$VERSION = '1.17_62';
+$VERSION = '1.18.02';
 
 use base 'Exporter';
 @EXPORT  = qw( $conf &read_config &run_smoke );
@@ -43,8 +43,14 @@ C<Test::Smoke> exports C<$conf> and C<read_config()> by default.
 
 sub read_config {
     my( $config_name ) = @_;
-    defined $config_name or $config_name = 'smokecurrent_config';
 
+    $config_name = 'smokecurrent_config' 
+        unless defined $config_name && length $config_name;
+    $config_name .= '_config' 
+        unless $config_name =~ /_config$/ || -f $config_name;
+
+    # Enable reloading by hackery
+    delete $INC{ $config_name } if exists $INC{ $config_name };
     eval { require $config_name };
     $ConfigError = $@ ? $@ : undef;
 
@@ -117,6 +123,7 @@ sub run_smoke {
         $smoker->tty( "Running smoke tests without \$ENV{PERLIO}\n" );
 
     unless ( $continue ) {
+        $smoker->_make( "-i distclean 2>/dev/null" );
         $smoker->ttylog( "Smoking patch $patch\n" ); 
         do_manifest_check( $conf->{ddir}, $smoker );
     }
@@ -163,7 +170,7 @@ sub skip_config {
 
 =head1 REVISION
 
-$Id: Smoke.pm 298 2003-07-31 21:03:26Z abeltje $
+$Id: Smoke.pm 350 2003-08-08 22:26:08Z abeltje $
 
 =head1 COPYRIGHT
 
