@@ -1,9 +1,9 @@
 package Test::Smoke::Smoker;
 use strict;
 
-# $Id: Smoker.pm 289 2003-07-30 18:11:33Z abeltje $
+# $Id: Smoker.pm 347 2003-08-08 18:15:39Z abeltje $
 use vars qw( $VERSION );
-$VERSION = '0.003';
+$VERSION = '0.005';
 
 use Cwd;
 use File::Spec;
@@ -25,6 +25,8 @@ my %CONFIG = (
     df_w32cc          => 'MSVC60',
     df_w32make        => 'nmake',
     df_w32args        => [ ],
+
+    df_makeopt        => "",
 );
 
 # Define some constants that we can use for
@@ -420,7 +422,7 @@ sub make_test {
         };
 #        $self->log( map { "    $_" } @nok );
         if (grep m/^All tests successful/, @nok) {
-            $self->log( "All tests successful\n" );
+            $self->log( "All tests successful.\n" );
             $self->tty( "\nOK, archive results ..." );
             $self->{patch} and $nok[0] =~ s/\./ for .patch = $self->{patch}./;
         } else {
@@ -459,16 +461,32 @@ sub extend_with_harness {
         } @harness : "@harness";
         my $changed_dir;
         chdir 't' and $changed_dir = 1;
+        my $harness_all_ok = 0;
         my $harness_out = join "", map {
             my( $name, $fail ) = 
-                m/(\S+\.t)\s+.+[?%]\s+(\d+(?:[-\s]+\d+)*)/;
-            my $dots = '.' x (40 - length $name );
-            "$name${dots}FAILED $fail\n";
-        } grep m/\S+\.t\s+.+?\d+(?:[-\s+]\d+)*/ =>
-            $self->_run( "./perl harness $harness" );
+                m/(\S+\.t)\s+.+%\s+([\d?]+(?:[-\s]+\d+)*)/;
+            if ( $name ) {
+                my $dots = '.' x (30 - length $name );
+                "    $name${dots}FAILED $fail\n";
+            } else {
+                ( $fail ) = m/^\s+(\d+(?:[-\s]+\d+)*)/;
+                " " x 41 . "$fail\n";
+            }
+        } grep m/^\s+\d+(?:[-\s]+\d+)/ ||
+               m/\S+\.t\s+.+%\s+[\d?]+(?:[-\s+]\d+)*/ => map {
+            /All tests successful/ && $harness_all_ok++;
+            $self->{v} > 1 and $self->tty( $_ );
+            $_;
+        } $self->_run( "./perl harness $harness" );
         $harness_out =~ s/^\s*$//;
-        $harness_out ||= join "", map "    $_" => @nok;
-        $self->ttylog("\n", $harness_out );
+        if ( $harness_all_ok ) {
+            $harness_out ||= @nok
+                ? "Inconsistent testresults:\n" . join "", map "    $_" => @nok
+                : "All tests successful.";
+        } else {
+            $harness_out ||= join "", map "    $_" => @nok;
+        }
+        $self->ttylog("\n", $harness_out, "\n" );
         $changed_dir and chdir File::Spec->updir;
     }
 }
@@ -554,6 +572,7 @@ stuff to help MSWin32 (the right maker, the directory).
 sub _make {
     my $self = shift;
     my $cmd = shift;
+    $self->{makeopt} and $cmd = "$self->{makeopt} $cmd";
 
     $self->{is_win32} or return $self->_run( "make $cmd" );
 
