@@ -11,7 +11,7 @@ use strict;
 use Test::Smoke;
 use vars qw($VERSION);
 $VERSION = Test::Smoke->VERSION; 
-# $Id: mkovz.pl 300 2003-07-31 22:50:09Z abeltje $
+# $Id: mkovz.pl 334 2003-08-07 01:01:23Z abeltje $
 
 use File::Spec;
 use Cwd;
@@ -150,7 +150,7 @@ for (<OUT>) {
         }
         next;
     }
-    if (m/^\s*Smoking patch (\d+)/) {
+    if (m/^\s*Smoking patch (\d+(?:\.\d+\.\d+-RC\d+)?)/) {
         $rpt{patch} = $1;
         next;
     }
@@ -187,6 +187,9 @@ for (<OUT>) {
         $rpt{$conf}{$debug}{$perlio} = $rpt{$conf}{$debug}{minitest} || "O";
         next;
     }
+    if ( m/Inconsistent testresults/ ) {
+        push @{ $rpt{$conf}{$debug}{$perlio} }, $_;
+    }
     if (m/^\s*Skipped this configuration/) {
 	if ($^O =~ m/^(?: hpux | freebsd )$/x) {
 	    (my $dup = $conf) =~ s/ -Duselongdouble//;
@@ -213,12 +216,12 @@ for (<OUT>) {
         }
         next;
     }
-    if (m/^\s*Unable\ to
-          \ (?=([cbmt]))(?:build|configure|make|test)
-          \ (anything\ but\ mini)?perl/x) {
-        $2 and $1 = uc $1; # M for no perl but miniperl
+    if (my( $status, $mini ) = m/^\s*Unable\ to
+                                 \ (?=([cbmt]))(?:build|configure|make|test)
+                                 \ (anything\ but\ mini)?perl/x) {
+        $mini and $status = uc $status; # M for no perl but miniperl
         foreach my $layer ( @layers ) {
-            $rpt{$conf}{$debug}{ $layer }  = $1;
+            $rpt{$conf}{$debug}{ $layer }  = $status;
         }
         next;
     }
@@ -239,6 +242,10 @@ for (<OUT>) {
         push @{$rpt{$conf}{$debug}{$perlio}}, $_;
         next;
     }
+    if ( /^\s+\d+(?:[-\s]+\d+)*/ ) {
+        push @{$rpt{$conf}{$debug}{$perlio}}, $_;
+        next;
+    }
 }
 
 $Config{ccvers}	||= $Config{gccversion} || $Config{ccversion};
@@ -254,6 +261,7 @@ Automated smoke report for $Config{version} patch $rpt{patch} on $Config{osname}
 Report by Test::Smoke v$VERSION (perl $this_pver)$time_msg
 
 O = OK  F = Failure(s), extended report at the bottom
+X = test(s) failed under TEST but not under harness
 ? = still running or test results not (yet) available
 Build failures during:       - = unknown or N/A
 c = Configure, m = make, M = make (after miniperl), t = make test-prep
@@ -273,7 +281,7 @@ $common_cfg = join " ", sort keys %common_args;
 
 $common_cfg ||= 'none';
 
-my %count = ( O => 0, F => 0, M => 0, m => 0, c => 0, o => 0, t => 0);
+my %count = ( O => 0, F => 0, X => 0, M => 0, m => 0, c => 0, o => 0, t => 0);
 my @fail;
 for my $conf (@confs) {
     ( $rpt_stat, $rpt_config ) = ( "", $conf );
@@ -285,7 +293,9 @@ for my $conf (@confs) {
 
 	    my $res = $rpt{$conf}{$debug}{$perlio};
 	    if (ref $res) {
-                $rpt_stat .= $bldenv eq 'minitest' ? "M " : "F ";
+                my $stat_x = grep /Inconsistent testresults/ => $res->[0];
+                $rpt_stat .= $bldenv eq 'minitest' 
+                    ? "M " : $stat_x ? "X " : "F ";
 		my $s_conf = $conf;
 		$debug and substr ($s_conf, 0, 0) = "-DDEBUGGING ";
 		if ( $perlio eq "stdio" && ref $rpt{$conf}{$debug}{perlio} 
@@ -318,7 +328,7 @@ for my $conf (@confs) {
     } split ' ', $rpt_stat;
 }
 
-my @rpt_sum_stat = grep $count{ $_ } > 0 => qw( F M m c t );
+my @rpt_sum_stat = grep $count{ $_ } > 0 => qw( X F M m c t );
 my $rpt_summary = '';
 if ( @rpt_sum_stat ) {
     $rpt_summary = "FAIL(" . join( "", @rpt_sum_stat ) . ")";
